/*****************************************************************************
 *  rspwrmeter.h
 *
 *  Rohde & Schwarz Power Meter Instrument Driver
 *  Original Release: August 2014
 *  By: Jiri Kominek, Lukas Hynek
 *
 *  Purpose: VXI Plug&Play instrument driver for R&S NRP2
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *  Copyright (c) 2014, Rohde & Schwarz GmbH & Co. KG
 *  All rights reserved.
 *****************************************************************************/

#ifndef __RSPWRMETER_HEADER
#define __RSPWRMETER_HEADER

#include "rscore.h"
#include "rspwrmeter_attributes.h"
#include "rspwrmeter_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSPWRMETER_CLASS_DRIVER_DESCRIPTION           ""
#define RSPWRMETER_CLASS_DRIVER_PREFIX                ""
#define RSPWRMETER_CLASS_DRIVER_VENDOR                ""
#define RSPWRMETER_CLASS_DRIVER_REVISION              ""
#define RSPWRMETER_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSPWRMETER_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSPWRMETER_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSPWRMETER_SPECIFIC_DRIVER_PREFIX             "RSPWRMETER"
#define RSPWRMETER_SPECIFIC_DRIVER_LOCATOR            ""
#define RSPWRMETER_SPECIFIC_DRIVER_VENDOR             ""
#define RSPWRMETER_MAJOR_VERSION                      2L    /* Instrument driver major version          */
#define RSPWRMETER_MINOR_VERSION                      60L    /* Instrument driver minor version          */
#define RSPWRMETER_MINOR_MINOR_VERSION                0L    /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSPWRMETER_SUPPORTED_INSTRUMENT_MODELS        "NRP2,NRX,NRQ6,NRPM,NRP-18S,NRPxxS/SN,NRP33SN-V,NRPxxT/TN/TWG,NRPxxA/AN"    /* Instrument driver supported model(s)     */
#define RSPWRMETER_GROUP_CAPABILITIES                 ""
#define RSPWRMETER_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSPWRMETER_SIMULATION_ID_QUERY      "Rohde&Schwarz,NRP2,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSPWRMETER_VALID_ID_RESPONSE_STRING "Rohde&Schwarz,NR"      /* Valid response for identification query */
#define RSPWRMETER_SIMULATION_OPT_QUERY     "B1"      /* Simulated response for *OPT? command */

#define RSPWRMETER_OPC_TIMEOUT              30000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSPWRMETER_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSPWRMETER_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSPWRMETER_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSPWRMETER_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSPWRMETER_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSPWRMETER_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSPWRMETER_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSPWRMETER_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSPWRMETER_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSPWRMETER_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSPWRMETER_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSPWRMETER_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSPWRMETER_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSPWRMETER_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSPWRMETER_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSPWRMETER_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSPWRMETER_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSPWRMETER_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSPWRMETER_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSPWRMETER_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSPWRMETER_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSPWRMETER_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSPWRMETER_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSPWRMETER_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSPWRMETER_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSPWRMETER_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSPWRMETER_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSPWRMETER_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSPWRMETER_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSPWRMETER_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSPWRMETER_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */
#define RSPWRMETER_ATTR_DISP_SIZE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSPWRMETER_ATTR_DISP_SELECTED_WINDOW                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSPWRMETER_ATTR_DISP_MSG_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSPWRMETER_ATTR_DISP_MSG_CLEAR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSPWRMETER_ATTR_DISP_MSG_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSPWRMETER_ATTR_CHANNEL_ZERO_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSPWRMETER_ATTR_CHANNEL_ZERO_ONCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSPWRMETER_ATTR_CHANNEL_FAST_ZERO_ONCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSPWRMETER_ATTR_CHANNEL_FREQUENCY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSPWRMETER_ATTR_CHANNEL_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSPWRMETER_ATTR_CHANNEL_AUXILIARY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSPWRMETER_ATTR_CHANNEL_SELECTED_TIMEGATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSPWRMETER_ATTR_CHANNEL_DISPLAY_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSPWRMETER_ATTR_CHANNEL_DISPLAY_NAME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSPWRMETER_ATTR_CHANNEL_DISPLAY_RESOLUTION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSPWRMETER_ATTR_CHANNEL_DISPLAY_TIMESLOT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSPWRMETER_ATTR_CHANNEL_DISPLAY_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSPWRMETER_ATTR_CHANNEL_DISPLAY_ADDITIONAL_INFO                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSPWRMETER_ATTR_CHANNEL_DISPLAY_ERRORLIST_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSPWRMETER_ATTR_DISPLAY_POWER_PULSE_DROOP_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 0
#define RSPWRMETER_ATTR_CHANNEL_ANALOG_METER_UPPER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSPWRMETER_ATTR_CHANNEL_ANALOG_METER_UPPER_POWER                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSPWRMETER_ATTR_CHANNEL_ANALOG_METER_UPPER_RATIO                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSPWRMETER_ATTR_CHANNEL_ANALOG_METER_LOWER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSPWRMETER_ATTR_CHANNEL_ANALOG_METER_LOWER_POWER                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSPWRMETER_ATTR_CHANNEL_ANALOG_METER_LOWER_RATIO                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSPWRMETER_ATTR_CHANNEL_VBW_LIST                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSPWRMETER_ATTR_CHANNEL_VBW                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSPWRMETER_ATTR_CHANNEL_AVER_RESET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSPWRMETER_ATTR_CHANNEL_AVER_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSPWRMETER_ATTR_CHANNEL_AVER_COUNT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSPWRMETER_ATTR_CHANNEL_AVER_COUNT_AUTO                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSPWRMETER_ATTR_CHANNEL_AVER_DOMAIN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 339
#define RSPWRMETER_ATTR_CHANNEL_AVER_TERMINAL_CONTROL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSPWRMETER_ATTR_CHANNEL_AVER_AUTO_MODE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSPWRMETER_ATTR_CHANNEL_AVER_AUTO_MTIME                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSPWRMETER_ATTR_CHANNEL_AVER_AUTO_RESOLUTION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSPWRMETER_ATTR_CHANNEL_AVER_AUTO_TIMESLOT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSPWRMETER_ATTR_CHANNEL_AVER_AUTO_NOISE_CONTENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSPWRMETER_ATTR_RANGE_AUTO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSPWRMETER_ATTR_RANGE_PATH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSPWRMETER_ATTR_RANGE_CROSSOVER_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_IMMEDIATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_SOURCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_COUNT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_SLOPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_DELAY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_DELAY_AUTO                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_DROPOUT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_HOLDOFF                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_HYSTERESIS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_MASTER_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_SENDER_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 397
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_MASTER_PORT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 259
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_SENDER_PORT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 398
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_SYNCHRONIZE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_SYNCHRONIZE_PORT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 332
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_AUTO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_AUTO_LEVEL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 260
#define RSPWRMETER_ATTR_CHANNEL_AUTO_TRIGGER_DELAY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 333
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_AUTO_EXECUTED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 261
#define RSPWRMETER_ATTR_CHANNEL_TRIGGER_EXTERNAL_IMPEDANCE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 262
#define RSPWRMETER_ATTR_TRIGGER_JITTER_SUPPRESSION_METHOD                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 340
#define RSPWRMETER_ATTR_TRIGGER_JITTER_SUPPRESSION_CURRENT_VALUE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 341
#define RSPWRMETER_ATTR_TRIGGER_JITTER_SUPPRESSION_TRIGGER_OFFSET           RS_SPECIFIC_PUBLIC_ATTR_BASE + 342
#define RSPWRMETER_ATTR_CHANNEL_SENSOR_REBOOT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSPWRMETER_ATTR_CHANNEL_SENSOR_RESET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSPWRMETER_ATTR_CHANNEL_SENSOR_INFO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSPWRMETER_ATTR_CORR_OFFSET_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSPWRMETER_ATTR_CORR_OFFSET_VALUE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSPWRMETER_ATTR_CORR_OFFSET_TABLE_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSPWRMETER_ATTR_CORR_OFFSET_SELECTED_TABLE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define RSPWRMETER_ATTR_CORR_OFFSET_FD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSPWRMETER_ATTR_CORR_SPARAM_DEVICE_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define RSPWRMETER_ATTR_CORR_SPARAM_DEVICE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSPWRMETER_ATTR_CORR_SPARAM_LIST                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 263
#define RSPWRMETER_ATTR_CORR_SGAMMA_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSPWRMETER_ATTR_CORR_SGAMMA_MAGNITUDE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSPWRMETER_ATTR_CORR_SGAMMA_PHASE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSPWRMETER_ATTR_CORR_RGAMMA_MAGNITUDE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define RSPWRMETER_ATTR_CORR_RGAMMA_PHASE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define RSPWRMETER_ATTR_DCYCLE_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define RSPWRMETER_ATTR_DCYCLE_VALUE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define RSPWRMETER_ATTR_NOISE_CORRECTION_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 343
#define RSPWRMETER_ATTR_IGAMMA_MAGNITUDE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 399
#define RSPWRMETER_ATTR_IGAMMA_PHASE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 400
#define RSPWRMETER_ATTR_IGAMMA_EXPANDED_UNCERTAINTY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 401
#define RSPWRMETER_ATTR_CHANNEL_CONTAV_APERTURE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define RSPWRMETER_ATTR_CHANNEL_CONTAV_BUFFER_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 80
#define RSPWRMETER_ATTR_CHANNEL_CONTAV_BUFFER_SIZE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 81
#define RSPWRMETER_ATTR_CHANNEL_CONTAV_BUFFER_COUNT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 264
#define RSPWRMETER_ATTR_CHANNEL_CONTAV_BUFFER_CLEAR                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 287
#define RSPWRMETER_ATTR_CHANNEL_CONTAV_SMOOTHING_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define RSPWRMETER_ATTR_CHANNEL_CONTAV_FAST_UNCHOPPED_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 294
#define RSPWRMETER_ATTR_CHANNEL_BURSTAV_DROPOUT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSPWRMETER_ATTR_CHANNEL_BURSTAV_EXCLUDE_START                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 85
#define RSPWRMETER_ATTR_CHANNEL_BURSTAV_EXCLUDE_STOP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 86
#define RSPWRMETER_ATTR_CHANNEL_BURSTAV_LENGTH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 265
#define RSPWRMETER_ATTR_CHANNEL_TRACE_OFFSET_TIME                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 87
#define RSPWRMETER_ATTR_CHANNEL_TRACE_TIME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 88
#define RSPWRMETER_ATTR_TRACE_TIME_AUTO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 344
#define RSPWRMETER_ATTR_CHANNEL_TRACE_POINTS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 89
#define RSPWRMETER_ATTR_CHANNEL_TRACE_LOWER_LIMIT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 91
#define RSPWRMETER_ATTR_CHANNEL_TRACE_UPPER_LIMIT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 92
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MINIMUM_SLOT_WIDTH                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 266
#define RSPWRMETER_ATTR_NUMBER_OF_SAMPLES                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345
#define RSPWRMETER_ATTR_SAMPLE_RATE_FOR_TRACE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346
#define RSPWRMETER_ATTR_CHANNEL_TRACE_FILTER_AVER_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 94
#define RSPWRMETER_ATTR_CHANNEL_TRACE_FILTER_AVER_COUNT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 95
#define RSPWRMETER_ATTR_CHANNEL_TRACE_FILTER_AVER_COUNT_AUTO                RS_SPECIFIC_PUBLIC_ATTR_BASE + 96
#define RSPWRMETER_ATTR_CHANNEL_TRACE_FILTER_TERMINAL_CONTROL               RS_SPECIFIC_PUBLIC_ATTR_BASE + 97
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 98
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_ALGORITHM                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 99
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_OFFSET_TIME                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 100
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_TIME                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 101
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_AUTO_TRANSFER                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 102
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_PULSE_DUTY_CYCLE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 103
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_PULSE_WIDTH                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 104
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_PULSE_PERIOD                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 105
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_PULSE_SEPARATION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 106
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_POWER_AVERAGE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 107
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_POWER_MAXIMUM                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 108
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_POWER_MINIMUM                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 109
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_POWER_BASE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 110
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_POWER_TOP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 111
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_POWER_DROOP                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 0
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_TRANS_REFERENCE_LEVEL            RS_SPECIFIC_PUBLIC_ATTR_BASE + 112
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_TRANS_HIGH_REFERENCE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 113
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_TRANS_LOW_REFERENCE              RS_SPECIFIC_PUBLIC_ATTR_BASE + 114
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_TRANS_POS_DURATION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 115
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_TRANS_POS_OCCURRENCE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_TRANS_POS_OVERSHOOT              RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_TRANS_NEG_DURATION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_TRANS_NEG_OCCURRENCE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSPWRMETER_ATTR_CHANNEL_TRACE_MEAS_TRANS_NEG_OVERSHOOT              RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSPWRMETER_ATTR_CHANNEL_STAT_OFFSET_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 122
#define RSPWRMETER_ATTR_CHANNEL_STAT_TIME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 123
#define RSPWRMETER_ATTR_CHANNEL_STAT_SAMPLES                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 124
#define RSPWRMETER_ATTR_CHANNEL_STAT_MID_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 125
#define RSPWRMETER_ATTR_CHANNEL_STAT_MID_LENGTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 126
#define RSPWRMETER_ATTR_CHANNEL_STAT_SCALE_RLEVEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 127
#define RSPWRMETER_ATTR_CHANNEL_STAT_SCALE_POINTS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 128
#define RSPWRMETER_ATTR_CHANNEL_STAT_SCALE_RANGE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 129
#define RSPWRMETER_ATTR_CHANNEL_STAT_SCALE_MIN_WIDTH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define RSPWRMETER_ATTR_CHANNEL_STAT_POWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSPWRMETER_ATTR_CHANNEL_STAT_HORIZONTAL_DATA                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSPWRMETER_ATTR_CHANNEL_STAT_VERTICAL_POSITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSPWRMETER_ATTR_CHANNEL_STAT_ABS_POWER_POSITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSPWRMETER_ATTR_CHANNEL_STAT_PEAK_POWER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 135
#define RSPWRMETER_ATTR_CHANNEL_STAT_AVERAGE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSPWRMETER_ATTR_CHANNEL_TIMESLOT_COUNT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 137
#define RSPWRMETER_ATTR_CHANNEL_TIMESLOT_WIDTH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSPWRMETER_ATTR_CHANNEL_TIMESLOT_MID_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define RSPWRMETER_ATTR_CHANNEL_TIMESLOT_MID_OFFSET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSPWRMETER_ATTR_CHANNEL_TIMESLOT_MID_LENGTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 141
#define RSPWRMETER_ATTR_CHANNEL_TIMESLOT_EXCLUDE_START                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 142
#define RSPWRMETER_ATTR_CHANNEL_TIMESLOT_EXCLUDE_STOP                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 143
#define RSPWRMETER_ATTR_CHANNEL_GATE_OFFSET_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 144
#define RSPWRMETER_ATTR_CHANNEL_GATE_TIME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 145
#define RSPWRMETER_ATTR_CHANNEL_GATE_MID_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 146
#define RSPWRMETER_ATTR_CHANNEL_GATE_MID_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 147
#define RSPWRMETER_ATTR_CHANNEL_GATE_MID_LENGTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 148
#define RSPWRMETER_ATTR_ACLR_APERTURE_TIME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347
#define RSPWRMETER_ATTR_ACLR_SPACING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348
#define RSPWRMETER_ATTR_VOLT_IQ_SAMPLE_RATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349
#define RSPWRMETER_ATTR_VOLT_IQ_SAMPLE_COUNT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350
#define RSPWRMETER_ATTR_CHANNEL_CAL_DEVIATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 152
#define RSPWRMETER_ATTR_CHANNEL_CAL_REFERENCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 153
#define RSPWRMETER_ATTR_CHANNEL_CAL_DATA_BLOCK_LENGTH                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 267
#define RSPWRMETER_ATTR_CHANNEL_CAL_USER_DATA_BLOCK_LENGTH                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 268
#define RSPWRMETER_ATTR_AUTOSET_FREQUENCY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351
#define RSPWRMETER_ATTR_RESOLUTION_BANDWIDTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353
#define RSPWRMETER_ATTR_CURRENT_RESOLUTION_BANDWIDTH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354
#define RSPWRMETER_ATTR_FILTER_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355
#define RSPWRMETER_ATTR_AUTOSET_FILTER_TYPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356
#define RSPWRMETER_ATTR_BANDWIDTH_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357
#define RSPWRMETER_ATTR_INPUT_ATTENUATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358
#define RSPWRMETER_ATTR_INPUT_ATTENUATION_AUTO                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359
#define RSPWRMETER_ATTR_AUTOSET_INPUT_ATTENUATION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360
#define RSPWRMETER_ATTR_LOCAL_OSCILLATOR_OUTPUT_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361
#define RSPWRMETER_ATTR_LOCAL_OSCILLATOR_FREQUENCY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362
#define RSPWRMETER_ATTR_IF_SIDEBAND_AUTO_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363
#define RSPWRMETER_ATTR_IF_SIDEBAND_SELECTED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 364
#define RSPWRMETER_ATTR_IF_SIDEBAND_FREQUENCY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 365
#define RSPWRMETER_ATTR_FREQUENCY_TRACKING_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 366
#define RSPWRMETER_ATTR_FREQUENCY_TRACKING_CURRENT_STATE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 367
#define RSPWRMETER_ATTR_FREQUENCY_TRACKING_CURRENT_FREQUENCY                RS_SPECIFIC_PUBLIC_ATTR_BASE + 368
#define RSPWRMETER_ATTR_CHANNEL_ZERO_ALL_ONCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 329
#define RSPWRMETER_ATTR_CHANNEL_FAST_ZERO_ALL_ONCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 330
#define RSPWRMETER_ATTR_CHANNELS_ZERO_ALL_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 156
#define RSPWRMETER_ATTR_REF_OSC_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 159
#define RSPWRMETER_ATTR_REFERENCE_OSCILLATOR_SOURCE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 369
#define RSPWRMETER_ATTR_REFERENCE_OSCILLATOR_REF_FREQUENCY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 370
#define RSPWRMETER_ATTR_REFERENCE_OSCILLATOR_USB_FREQUENCY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 371
#define RSPWRMETER_ATTR_REFERENCE_OSCILLATOR_CLK_FREQUENCY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 372
#define RSPWRMETER_ATTR_REFERENCE_IO_OUTPUT_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 373
#define RSPWRMETER_ATTR_SAMPLE_CLOCK_OUTPUT_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 374
#define RSPWRMETER_ATTR_TRIGGER_IMMEDIATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 160
#define RSPWRMETER_ATTR_TRIGGER_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 161
#define RSPWRMETER_ATTR_TRIGGER_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 162
#define RSPWRMETER_ATTR_TRIGGER_SLOPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 163
#define RSPWRMETER_ATTR_TRIGGER_LEVEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 164
#define RSPWRMETER_ATTR_TRIGGER_DELAY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 165
#define RSPWRMETER_ATTR_TRIGGER_DELAY_AUTO                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 166
#define RSPWRMETER_ATTR_TRIGGER_DROPOUT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 167
#define RSPWRMETER_ATTR_TRIGGER_HOLDOFF                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 168
#define RSPWRMETER_ATTR_TRIGGER_HYSTERESIS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 169
#define RSPWRMETER_ATTR_TRIGGER_SYNCHRONIZE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 170
#define RSPWRMETER_ATTR_TRIGGER_AUTO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 171
#define RSPWRMETER_ATTR_MEAS_DISABLE_INITIATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSPWRMETER_ATTR_MEAS_CONTINUOUS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSPWRMETER_ATTR_MEAS_SEND_SOFTWARE_TRIGGER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSPWRMETER_ATTR_MEAS_BLOCK_UNITS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSPWRMETER_ATTR_MEAS_BLOCK_RATIO_UNITS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSPWRMETER_ATTR_MEAS_GATE_CALCULATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 181
#define RSPWRMETER_ATTR_MEAS_DISPLAY_DATA_COUNT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 182
#define RSPWRMETER_ATTR_MEAS_DISPLAY_DATA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 183
#define RSPWRMETER_ATTR_MEAS_DISPLAY_SDEVIATION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSPWRMETER_ATTR_MEAS_DISPLAY_MEAN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 185
#define RSPWRMETER_ATTR_MEAS_DISPLAY_PEAK_TO_PEAK                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSPWRMETER_ATTR_MEAS_DISPLAY_MAXIMUM                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSPWRMETER_ATTR_MEAS_DISPLAY_MINIMUM                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSPWRMETER_ATTR_RELATIVE_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSPWRMETER_ATTR_RELATIVE_REFERENCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 191
#define RSPWRMETER_ATTR_RELATIVE_REFERENCE_POWER_RATIO                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 193
#define RSPWRMETER_ATTR_LIMITS_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 196
#define RSPWRMETER_ATTR_LIMITS_WARNING_BEEP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 197
#define RSPWRMETER_ATTR_LIMITS_FAIL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 198
#define RSPWRMETER_ATTR_LIMITS_FAIL_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 199
#define RSPWRMETER_ATTR_LIMITS_AUTO_RESET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 200
#define RSPWRMETER_ATTR_LIMITS_UPPER_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 201
#define RSPWRMETER_ATTR_LIMITS_UPPER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 202
#define RSPWRMETER_ATTR_LIMITS_UPPER_POWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 203
#define RSPWRMETER_ATTR_LIMITS_UPPER_RATIO                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 204
#define RSPWRMETER_ATTR_LIMITS_LOWER_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 205
#define RSPWRMETER_ATTR_LIMITS_LOWER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 206
#define RSPWRMETER_ATTR_LIMITS_LOWER_POWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 207
#define RSPWRMETER_ATTR_LIMITS_LOWER_RATIO                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 208
#define RSPWRMETER_ATTR_MEAS_MATH_EXPRESSION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 209
#define RSPWRMETER_ATTR_CHANNEL_MEAS_MATH_EXPRESSION_CATALOG                RS_SPECIFIC_PUBLIC_ATTR_BASE + 210
#define RSPWRMETER_ATTR_MEAS_TRACE_XPOSITION1                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 211
#define RSPWRMETER_ATTR_MEAS_TRACE_XPOSITION2                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 212
#define RSPWRMETER_ATTR_MEAS_TRACE_YPOSITION1                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 213
#define RSPWRMETER_ATTR_MEAS_TRACE_YPOSITION2                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 214
#define RSPWRMETER_ATTR_MEAS_TRACE_XDELTA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 215
#define RSPWRMETER_ATTR_MEAS_TRACE_YDELTA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSPWRMETER_ATTR_CHANNEL_MEAS_ABORT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSPWRMETER_ATTR_CHANNEL_MEAS_INITIATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 218
#define RSPWRMETER_ATTR_CHANNEL_MEAS_INITIATE_WAIT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 378
#define RSPWRMETER_ATTR_CHANNEL_MEAS_DISABLE_INITIATE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 219
#define RSPWRMETER_ATTR_CHANNEL_MEAS_CONTINUOUS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 220
#define RSPWRMETER_ATTR_MEASUREMENT_PATH_SENSOR_PRESENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 336
#define RSPWRMETER_ATTR_MEASUREMENT_PATH_SENSOR_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 337
#define RSPWRMETER_ATTR_SYSTEM_REBOOT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 223
#define RSPWRMETER_ATTR_SYSTEM_RESTART                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 404
#define RSPWRMETER_ATTR_SYSTEM_RESULT_UPDATE_TIME                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 405
#define RSPWRMETER_ATTR_SYSTEM_STATUS_UPDATE_TIME                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 406
#define RSPWRMETER_ATTR_SYSTEM_SPEED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 224
#define RSPWRMETER_ATTR_SYSTEM_TEST_LEVELS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 376
#define RSPWRMETER_ATTR_SYSTEM_VERSION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 226
#define RSPWRMETER_ATTR_SYSTEM_INFORMATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 293
#define RSPWRMETER_ATTR_SYSTEM_SENSOR_NAME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 377
#define RSPWRMETER_ATTR_SYSTEM_ERROR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 221
#define RSPWRMETER_ATTR_SYSTEM_ERROR_COUNT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 288
#define RSPWRMETER_ATTR_STATUS_PRESET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 315
#define RSPWRMETER_ATTR_ID_QUERY_RESPONSE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 392
#define RSPWRMETER_ATTR_PRESET_DEVICE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 317
#define RSPWRMETER_ATTR_LOGGING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 318
#define RSPWRMETER_ATTR_SYSTEM_CLOCK_SOURCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 272
#define RSPWRMETER_ATTR_SYSTEM_LOWER_POWER_MEASUREMENT_LIMIT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 289
#define RSPWRMETER_ATTR_SYSTEM_IO_OUT1_TTL_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 227
#define RSPWRMETER_ATTR_SYSTEM_IO_OUT1_TTL_ACTIVE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 228
#define RSPWRMETER_ATTR_SYSTEM_IO_OUT1_TTL_FAIL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 229
#define RSPWRMETER_ATTR_SYSTEM_IO_OUT1_TTL_HIGH_VOLTAGE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 230
#define RSPWRMETER_ATTR_SYSTEM_IO_OUT1_TTL_LOW_VOLTAGE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 231
#define RSPWRMETER_ATTR_SYSTEM_IO_OUT1_TTL_LIMITED_CALC_BLOCK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 232
#define RSPWRMETER_ATTR_SYSTEM_IO_OUT1_TRIGGER_OUTPUT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 233
#define RSPWRMETER_ATTR_SYSTEM_IO_ANALOG_OUTPUT_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 234
#define RSPWRMETER_ATTR_SYSTEM_IO_ANALOG_OUTPUT_SELECTED_CALC_BLOCK         RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSPWRMETER_ATTR_SYSTEM_IO_ANALOG_OUTPUT_UPPER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSPWRMETER_ATTR_SYSTEM_IO_ANALOG_OUTPUT_UPPER_POWER                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSPWRMETER_ATTR_SYSTEM_IO_ANALOG_OUTPUT_UPPER_RATIO                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 238
#define RSPWRMETER_ATTR_SYSTEM_IO_ANALOG_OUTPUT_LOWER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 239
#define RSPWRMETER_ATTR_SYSTEM_IO_ANALOG_OUTPUT_LOWER_POWER                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSPWRMETER_ATTR_SYSTEM_IO_ANALOG_OUTPUT_LOWER_RATIO                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define RSPWRMETER_ATTR_SYSTEM_MISC_DISPLAY_UPDATE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSPWRMETER_ATTR_SYSTEM_MISC_BRIGHTNESS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSPWRMETER_ATTR_SYSTEM_MISC_BEEP_START                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSPWRMETER_ATTR_SYSTEM_MISC_BEEP_STOP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 247
#define RSPWRMETER_ATTR_SYSTEM_MISC_BEEP_OVERLOAD                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 248
#define RSPWRMETER_ATTR_SYSTEM_MISC_BEEP_KEY_CLICK                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 249
#define RSPWRMETER_ATTR_SYSTEM_MISC_BEEP_TIME                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 250
#define RSPWRMETER_ATTR_SYSTEM_STD_CATALOG                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 251
#define RSPWRMETER_ATTR_SYSTEM_STD_SELECTED_STANDARD                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 252
#define RSPWRMETER_ATTR_SYSTEM_STD_PRESERVE_WINDOW_SETTINGS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 253
#define RSPWRMETER_ATTR_SYSTEM_STD_TRIGGER_SOURCE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_IP_ADDRESS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 273
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_IP_ADDRESS_SUBNET_MASK               RS_SPECIFIC_PUBLIC_ATTR_BASE + 274
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_IP_ADDRESS_GATEWAY                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 275
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_IP_ADDRESS_MODE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_IP_ADDRESS_INFO                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 277
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_RESET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 278
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_RESTART                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 280
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_STATUS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_DOMAIN                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 283
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_HOSTNAME                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 284
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_SOCKET_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 285
#define RSPWRMETER_ATTR_SYSTEM_NETWORK_SOCKET_PORT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 286
#define RSPWRMETER_ATTR_LED_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 290
#define RSPWRMETER_ATTR_LED_COLOR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 291

// rspwrmeter_rngTriggerSource
#define RSPWRMETER_VAL_TRG_IMM                                              0
#define RSPWRMETER_VAL_TRG_EXT                                              1
#define RSPWRMETER_VAL_TRG_INT                                              2
#define RSPWRMETER_VAL_TRG_BUS                                              3
#define RSPWRMETER_VAL_TRG_HOLD                                             4
#define RSPWRMETER_VAL_TRG_EXT2                                             5
#define RSPWRMETER_VAL_TRG_INTA                                             6
#define RSPWRMETER_VAL_TRG_INTB                                             7
#define RSPWRMETER_VAL_TRG_INTC                                             8
#define RSPWRMETER_VAL_TRG_INTD                                             9
#define RSPWRMETER_VAL_TRG_CHKSOURCE                                        10

// rspwrmeter_rngUnits
#define RSPWRMETER_VAL_UNIT_DBM                                             0
#define RSPWRMETER_VAL_UNIT_W                                               1
#define RSPWRMETER_VAL_UNIT_DBUV                                            2

// rspwrmeter_rngRatioUnits
#define RSPWRMETER_VAL_RATIO_UNIT_DB                                        0
#define RSPWRMETER_VAL_RATIO_UNIT_DPCT                                      1
#define RSPWRMETER_VAL_RATIO_UNIT_O                                         2

// rspwrmeter_rngSlope
#define RSPWRMETER_VAL_SLOPE_NEG                                            0
#define RSPWRMETER_VAL_SLOPE_POS                                            1

// rspwrmeter_rngChannelZeroState
#define RSPWRMETER_VAL_ZERO_STATE_OFF                                       0
#define RSPWRMETER_VAL_ZERO_STATE_ON                                        1

// rspwrmeter_rngAverageAutoFilterMode
#define RSPWRMETER_VAL_AUTO_FILTER_MODE_NORMAL                              0
#define RSPWRMETER_VAL_AUTO_FILTER_MODE_FIXED_NOISE                         1

// rspwrmeter_rngAverageTerminalControl
#define RSPWRMETER_VAL_AVER_TCONTROL_MOVING                                 0
#define RSPWRMETER_VAL_AVER_TCONTROL_REPEAT                                 1

// rspwrmeter_rngMeasurementMode
#define RSPWRMETER_VAL_MEAS_MODE_CONT_AV                                    0
#define RSPWRMETER_VAL_MEAS_MODE_TIMESLOT_AV                                1
#define RSPWRMETER_VAL_MEAS_MODE_TIMEGATE_AV                                2
#define RSPWRMETER_VAL_MEAS_MODE_BURST_AV                                   3
#define RSPWRMETER_VAL_MEAS_MODE_CCDF                                       4
#define RSPWRMETER_VAL_MEAS_MODE_PDF                                        5
#define RSPWRMETER_VAL_MEAS_MODE_TRACE                                      6
#define RSPWRMETER_VAL_MEAS_MODE_ACLR                                       7
#define RSPWRMETER_VAL_MEAS_MODE_IQ                                         8

// rspwrmeter_rngContAvSampling
#define RSPWRMETER_VAL_SAMPLING_FREQ1                                       0
#define RSPWRMETER_VAL_SAMPLING_FREQ2                                       1

// rspwrmeter_rngTraceTerminalControl
#define RSPWRMETER_VAL_TRACE_TERMINAL_CONTROL_MOVING                        0
#define RSPWRMETER_VAL_TRACE_TERMINAL_CONTROL_REPEAT                        1

// rspwrmeter_rngTraceMeasAlgorithm
#define RSPWRMETER_VAL_TRACE_MEAS_ALGORITHM_HISTOGRAM                       0
#define RSPWRMETER_VAL_TRACE_MEAS_ALGORITHM_INTEGRATION                     1
#define RSPWRMETER_VAL_TRACE_MEAS_ALGORITHM_PEAK                            2

// rspwrmeter_rngAuxiliary
#define RSPWRMETER_VAL_AUX_NONE                                             0
#define RSPWRMETER_VAL_AUX_MINMAX                                           1
#define RSPWRMETER_VAL_AUX_RNDMAX                                           2

// rspwrmeter_rngDisplayResolution
#define RSPWRMETER_VAL_DISP_RESOLUTION_SIGN1                                0
#define RSPWRMETER_VAL_DISP_RESOLUTION_SIGN2                                1
#define RSPWRMETER_VAL_DISP_RESOLUTION_SIGN3                                2
#define RSPWRMETER_VAL_DISP_RESOLUTION_SIGN4                                3

// rspwrmeter_rngDisplayMode
#define RSPWRMETER_VAL_DISPLAY_FORMAT_DIGITAL                               0
#define RSPWRMETER_VAL_DISPLAY_FORMAT_ANALOG                                1
#define RSPWRMETER_VAL_DISPLAY_FORMAT_GRAPHICAL                             2

// rspwrmeter_rngDisplayUpdate
#define RSPWRMETER_VAL_DISPLAY_UPDATE_NORMAL                                0
#define RSPWRMETER_VAL_DISPLAY_UPDATE_SLOW                                  1
#define RSPWRMETER_VAL_DISPLAY_UPDATE_FROZEN                                2

// rspwrmeter_rngTTLHighLow
#define RSPWRMETER_VAL_TTL_ACTIVE_LOW                                       0
#define RSPWRMETER_VAL_TTL_ACTIVE_HIGH                                      1

// rspwrmeter_rngMsgType
#define RSPWRMETER_VAL_DISP_MSG_QUERY                                       0
#define RSPWRMETER_VAL_DISP_MSG_MESSAGE                                     1

// rspwrmeter_rngDisplaySize
#define RSPWRMETER_VAL_DISP_SIZE_NORMAL                                     0
#define RSPWRMETER_VAL_DISP_SIZE_ZOOMED                                     1

// rspwrmeter_rngDisplayAdditionalInfo
#define RSPWRMETER_VAL_DISP_INFO_NONE                                       0
#define RSPWRMETER_VAL_DISP_INFO_NORMAL                                     1
#define RSPWRMETER_VAL_DISP_INFO_EXTREME                                    2
#define RSPWRMETER_VAL_DISP_INFO_STATISTIC                                  3

// rspwrmeter_rngCalculation
#define RSPWRMETER_VAL_CALC_PWR_AVG                                         0
#define RSPWRMETER_VAL_CALC_PWR_PEAK                                        1
#define RSPWRMETER_VAL_CALC_PWR_RANDOM                                      2
#define RSPWRMETER_VAL_CALC_PWR_TRACE                                       3
#define RSPWRMETER_VAL_CALC_PWR_PEAK_TRACE                                  4
#define RSPWRMETER_VAL_CALC_PWR_RANDOM_TRACE                                5
#define RSPWRMETER_VAL_CALC_PWR_AVG_SWEEP1                                  6
#define RSPWRMETER_VAL_CALC_PWR_AVG_SWEEP2                                  7
#define RSPWRMETER_VAL_CALC_PWR_AVG_SWEEP3                                  8
#define RSPWRMETER_VAL_CALC_PWR_AVG_SWEEP4                                  9
#define RSPWRMETER_VAL_CALC_PWR_PTAV_SWEEP1                                 10
#define RSPWRMETER_VAL_CALC_PWR_PTAV_SWEEP2                                 11
#define RSPWRMETER_VAL_CALC_PWR_PTAV_SWEEP3                                 12
#define RSPWRMETER_VAL_CALC_PWR_PTAV_SWEEP4                                 13
#define RSPWRMETER_VAL_CALC_PWR_PEAK_SWEEP1                                 14
#define RSPWRMETER_VAL_CALC_PWR_PEAK_SWEEP2                                 15
#define RSPWRMETER_VAL_CALC_PWR_PEAK_SWEEP3                                 16
#define RSPWRMETER_VAL_CALC_PWR_PEAK_SWEEP4                                 17
#define RSPWRMETER_VAL_CALC_CCDF                                            18
#define RSPWRMETER_VAL_CALC_PDF                                             19

// rspwrmeter_rngCalculateBlock
#define RSPWRMETER_VAL_CALC_BLOCK1                                          0
#define RSPWRMETER_VAL_CALC_BLOCK2                                          1
#define RSPWRMETER_VAL_CALC_BLOCK3                                          2
#define RSPWRMETER_VAL_CALC_BLOCK4                                          3

// rspwrmeter_rngTTLCalculateBlock
#define RSPWRMETER_VAL_LIMIT_CALC_BLOCK1                                    0
#define RSPWRMETER_VAL_LIMIT_CALC_BLOCK2                                    1
#define RSPWRMETER_VAL_LIMIT_CALC_BLOCK3                                    2
#define RSPWRMETER_VAL_LIMIT_CALC_BLOCK4                                    3

// rspwrmeter_rngIntExt
#define RSPWRMETER_VAL_INT                                                  0
#define RSPWRMETER_VAL_EXT                                                  1

// rspwrmeter_rngRegisterGroup
#define RSPWRMETER_VAL_REGISTER_GROUP_OPER                                  0
#define RSPWRMETER_VAL_REGISTER_GROUP_QUES                                  1
#define RSPWRMETER_VAL_REGISTER_GROUP_DEVICE                                2
#define RSPWRMETER_VAL_REGISTER_GROUP_OPER_CAL                              3
#define RSPWRMETER_VAL_REGISTER_GROUP_OPER_LLFAIL                           4
#define RSPWRMETER_VAL_REGISTER_GROUP_OPER_ULFAIL                           5
#define RSPWRMETER_VAL_REGISTER_GROUP_OPER_MEAS                             6
#define RSPWRMETER_VAL_REGISTER_GROUP_OPER_SENSE                            7
#define RSPWRMETER_VAL_REGISTER_GROUP_OPER_TRIG                             8
#define RSPWRMETER_VAL_REGISTER_GROUP_QUES_CAL                              9
#define RSPWRMETER_VAL_REGISTER_GROUP_QUES_POW                              10
#define RSPWRMETER_VAL_REGISTER_GROUP_QUES_WIND                             11

// rspwrmeter_rngRegisterType
#define RSPWRMETER_VAL_REGISTER_TYPE_COND                                   0
#define RSPWRMETER_VAL_REGISTER_TYPE_EVEN                                   1
#define RSPWRMETER_VAL_REGISTER_TYPE_ENAB                                   2
#define RSPWRMETER_VAL_REGISTER_TYPE_PTR                                    3
#define RSPWRMETER_VAL_REGISTER_TYPE_NTR                                    4

// rspwrmeter_rngSystemSpeed
#define RSPWRMETER_VAL_SYSTEM_SPEED_NORMAL                                  0
#define RSPWRMETER_VAL_SYSTEM_SPEED_FAST                                    1

// RsPwrMeter_rngSystemLanguage
#define RSPWRMETER_VAL_SYSTEM_LANGUAGE_NRP                                  0
#define RSPWRMETER_VAL_SYSTEM_LANGUAGE_NRP2                                 1
#define RSPWRMETER_VAL_SYSTEM_LANGUAGE_HP436A                               2
#define RSPWRMETER_VAL_SYSTEM_LANGUAGE_HP437B                               3
#define RSPWRMETER_VAL_SYSTEM_LANGUAGE_HP438A                               4
#define RSPWRMETER_VAL_SYSTEM_LANGUAGE_E4418B                               5
#define RSPWRMETER_VAL_SYSTEM_LANGUAGE_E4419B                               6
#define RSPWRMETER_VAL_SYSTEM_LANGUAGE_N1911A                               7
#define RSPWRMETER_VAL_SYSTEM_LANGUAGE_N1912A                               8

// RsPwrMeter_rngIPAddressMode
#define RSPWRMETER_VAL_IP_ADDRESS_STATIC                                    0
#define RSPWRMETER_VAL_IP_ADDRESS_AUTO                                      1

// RsPwrMeter_rngSocketMode
#define RSPWRMETER_VAL_SOCKET_MODE_RAW                                      0
#define RSPWRMETER_VAL_SOCKET_MODE_AGILENT                                  1
#define RSPWRMETER_VAL_SOCKET_MODE_IEEE1174                                 2

// RsPwrMeter_rngExternalTriggerImpedance
#define RSPWRMETER_VAL_EXT_TRIGGER_IMPEDANCE_LOW                            0
#define RSPWRMETER_VAL_EXT_TRIGGER_IMPEDANCE_HIGH                           1

// RsPwrMeter_rngMasterPort
#define RSPWRMETER_VAL_TRIGGER_MASTER_PORT_EXT_1                            1
#define RSPWRMETER_VAL_TRIGGER_MASTER_PORT_EXT_2                            2

// RsPwrMeter_rngLEDMode
#define RSPWRMETER_VAL_LED_USER                                             0
#define RSPWRMETER_VAL_LED_SENSOR                                           1

// RsPwrMeter_rngTriggerExternalImpedance
#define RSPWRMETER_VAL_LOW                                                  0
#define RSPWRMETER_VAL_HIGH                                                 1

// RsPwrMeter_rngTraceResultType
#define RSPWRMETER_VAL_TRACE_RESULT_TYPE_AVG                                0
#define RSPWRMETER_VAL_TRACE_RESULT_TYPE_MIN                                1
#define RSPWRMETER_VAL_TRACE_RESULT_TYPE_MAX                                2
#define RSPWRMETER_VAL_TRACE_RESULT_TYPE_RND                                3

// RsPwrMeter_rngChannelTriggerSynchronizePort
#define RSPWRMETER_VAL_SYNC_PORT_EXT1                                       0
#define RSPWRMETER_VAL_SYNC_PORT_EXT2                                       1

// RsPwrMeter_rngFilterType
#define RSPWRMETER_VAL_FILTER_FLAT                                          0
#define RSPWRMETER_VAL_FILTER_NORMAL                                        1
#define RSPWRMETER_VAL_FILTER_LTE                                           2
#define RSPWRMETER_VAL_FILTER_W3GPP                                         3

// RsPwrMeter_rngBandwidthType
#define RSPWRMETER_VAL_BWID_RESOLUTION                                      0
#define RSPWRMETER_VAL_BWID_SAMPLE_RATE                                     1

// RsPwrMeter_rngReferenceOscillatorSource
#define RSPWRMETER_VAL_ROSC_SOURCE_INTERNAL                                 0
#define RSPWRMETER_VAL_ROSC_SOURCE_USB                                      1
#define RSPWRMETER_VAL_ROSC_SOURCE_REF                                      2
#define RSPWRMETER_VAL_ROSC_SOURCE_CLK                                      3
#define RSPWRMETER_VAL_ROSC_SOURCE_EXT                                      4

// RsPwrMeter_rngAveragingDomain
#define RSPWRMETER_VAL_AVERAGING_DOMAIN_POWER                               0
#define RSPWRMETER_VAL_AVERAGING_DOMAIN_VIDEO                               1
#define RSPWRMETER_VAL_AVERAGING_DOMAIN_LINEAR                              2

// RsPwrMeter_rngIFSidebandSelected
#define RSPWRMETER_VAL_IF_SIDEBAND_LEFT                                     0
#define RSPWRMETER_VAL_IF_SIDEBAND_RIGHT                                    1

// RsPwrMeter_rngTriggerJitterSuppressionMethod
#define RSPWRMETER_VAL_JITTER_SUPPRESSION_NONE                              0
#define RSPWRMETER_VAL_JITTER_SUPPRESSION_COMPENSATE                        1
#define RSPWRMETER_VAL_JITTER_SUPPRESSION_MEASURE                           2

// RsPwrMeter_rngSenderPort
#define RSPWRMETER_VAL_TRIGGER_SENDER_PORT_EXT_1                            1
#define RSPWRMETER_VAL_TRIGGER_SENDER_PORT_EXT_2                            2

// RsPwrMeter_rngFetchResult
#define RSPWRMETER_VAL_MEAS_CONT_AVER                                       0
#define RSPWRMETER_VAL_MEAS_CONT_BURST                                      1
#define RSPWRMETER_VAL_MEAS_CONT_TIMESLOT                                   2

// RsPwrMeter_rngListCommands
#define RSPWRMETER_VAL_ALL_CMD                                              0
#define RSPWRMETER_VAL_DIFFERENT_CMD                                        1

//repcap Channel
#define RSPWRMETER_REPCAP_CHANNEL_CH0                                       0
#define RSPWRMETER_REPCAP_CHANNEL_CH1                                       1
#define RSPWRMETER_REPCAP_CHANNEL_CH2                                       2
#define RSPWRMETER_REPCAP_CHANNEL_CH3                                       3
#define RSPWRMETER_REPCAP_CHANNEL_CH4                                       4

//repcap CalculateBlock
#define RSPWRMETER_REPCAP_CALCULATEBLOCK_BL1                                1
#define RSPWRMETER_REPCAP_CALCULATEBLOCK_BL2                                2
#define RSPWRMETER_REPCAP_CALCULATEBLOCK_BL3                                3
#define RSPWRMETER_REPCAP_CALCULATEBLOCK_BL4                                4
#define RSPWRMETER_REPCAP_CALCULATEBLOCK_BL5                                5
#define RSPWRMETER_REPCAP_CALCULATEBLOCK_BL6                                6
#define RSPWRMETER_REPCAP_CALCULATEBLOCK_BL7                                7
#define RSPWRMETER_REPCAP_CALCULATEBLOCK_BL8                                8

//repcap Timegate
#define RSPWRMETER_REPCAP_TIMEGATE_TG1                                      1
#define RSPWRMETER_REPCAP_TIMEGATE_TG2                                      2
#define RSPWRMETER_REPCAP_TIMEGATE_TG3                                      3
#define RSPWRMETER_REPCAP_TIMEGATE_TG4                                      4

//repcap AnalogOutput
#define RSPWRMETER_REPCAP_ANALOGOUTPUT_OUT1                                 1
#define RSPWRMETER_REPCAP_ANALOGOUTPUT_OUT2                                 2

//repcap Gate
#define RSPWRMETER_REPCAP_GATE_G1                                           1
#define RSPWRMETER_REPCAP_GATE_G2                                           2

//repcap Path
#define RSPWRMETER_REPCAP_PATH_P1                                           1
#define RSPWRMETER_REPCAP_PATH_P2                                           2
#define RSPWRMETER_REPCAP_PATH_P3                                           3
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSPWRMETER_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSPWRMETER_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSPWRMETER_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSPWRMETER_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *------------------------ Attribute Value Defines -------------------------*
 ****************************************************************************/

    /*- Instrument specific attribute value definitions --------------------*/
#define RSPWRMETER_VAL_TRACE_MEAS_EDGE_RISE 0
#define RSPWRMETER_VAL_TRACE_MEAS_EDGE_FALL 1

#define RSPWRMETER_VAL_DATA_BLOCK_FACTORY 0
#define RSPWRMETER_VAL_DATA_BLOCK_USER    1

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rspwrmeter_init(ViRsrc     resourceName,
                                  ViBoolean  IDQuery,
                                  ViBoolean  resetDevice,
                                  ViSession* instrSession);

ViStatus _VI_FUNC rspwrmeter_InitWithOptions(ViRsrc     resourceName,
                                             ViBoolean  IDQuery,
                                             ViBoolean  resetDevice,
                                             ViString   optionString,
                                             ViSession* instrSession);

ViStatus _VI_FUNC rspwrmeter_ZeroAll(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_FastZeroAll(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_IsZeroCompleteAll(ViSession  instrSession,
                                               ViBoolean* zeroingComplete);

ViStatus _VI_FUNC rspwrmeter_MeasurementMode(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   measurementMode);

ViStatus _VI_FUNC rspwrmeter_SetAuxiliary(ViSession instrSession,
                                          ViInt32   channel,
                                          ViInt32   auxiliary);

ViStatus _VI_FUNC rspwrmeter_GetAuxiliary(ViSession instrSession,
                                          ViInt32   channel,
                                          ViInt32*  auxiliary);

ViStatus _VI_FUNC rspwrmeter_ConfigureUnits(ViSession instrSession,
                                            ViInt32   calculateBlock,
                                            ViInt32   units);

ViStatus _VI_FUNC rspwrmeter_ConfigureRangeAutoEnabled(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean rangeAutoEnabled);

ViStatus _VI_FUNC rspwrmeter_ConfigureRangePath(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   path);

ViStatus _VI_FUNC rspwrmeter_ConfigureRangeCrossoverLevel(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViReal64  crossoverLevel);

ViStatus _VI_FUNC rspwrmeter_ConfigureAveragingAutoEnabled(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViBoolean averagingAutoEnabled);

ViStatus _VI_FUNC rspwrmeter_ConfigureCorrectionFrequency(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViReal64  correctionFrequency);

ViStatus _VI_FUNC rspwrmeter_ConfigureDisplay(ViSession instrSession,
                                              ViInt32   channel,
                                              ViBoolean displayState,
                                              ViString  displayName,
                                              ViInt32   displayResolution,
                                              ViInt32   timeslot,
                                              ViInt32   displayMode,
                                              ViInt32   additionalInfo,
                                              ViBoolean errorlistState);

ViStatus _VI_FUNC rspwrmeter_AutoScalingAnalogMeter(ViSession instrSession,
                                                    ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_ConfigureAnalogMeterScaling(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViReal64  left,
                                                         ViReal64  right);

ViStatus _VI_FUNC rspwrmeter_ConfigureAnalogMeterPowerRange(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViReal64  lowerPower,
                                                            ViReal64  upperPower);

ViStatus _VI_FUNC rspwrmeter_ConfigureAnalogMeterPowerRatioRange(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  lowerPowerRatio,
                            ViReal64  upperPowerRatio);

ViStatus _VI_FUNC rspwrmeter_ConfigureDisplayPowerPulseDroopEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean droopEnabled);

ViStatus _VI_FUNC rspwrmeter_SetVideoBandwidth(ViSession instrSession,
                                               ViInt32   channel,
                                               ViString  bandwidth);

ViStatus _VI_FUNC rspwrmeter_GetVideoBandwidth(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   bufferSize,
                                               ViChar    bandwidth[]);

ViStatus _VI_FUNC rspwrmeter_GetVideoBandwidthList(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   bufferSize,
                                                   ViChar    bandwidthList[]);

ViStatus _VI_FUNC rspwrmeter_ResetRange(ViSession instrSession,
                                        ViInt32   calculateBlock);

ViStatus _VI_FUNC rspwrmeter_ResetAuxVal(ViSession instrSession,
                                         ViInt32   calculateBlock);

ViStatus _VI_FUNC rspwrmeter_ConfigureMonitoringFunction(ViSession instrSession,
                                                         ViInt32   calculateBlock,
                                                         ViBoolean monitoringState,
                                                         ViBoolean autoReset);

ViStatus _VI_FUNC rspwrmeter_ConfigureRange(ViSession instrSession,
                                            ViInt32   calculateBlock,
                                            ViBoolean lowerEnabled,
                                            ViReal64  rangeLower,
                                            ViBoolean upperEnabled,
                                            ViReal64  rangeUpper,
                                            ViBoolean warningBeep);

ViStatus _VI_FUNC rspwrmeter_ConfigurePowerRange(ViSession instrSession,
                                                 ViInt32   calculateBlock,
                                                 ViReal64  powerRangeLower,
                                                 ViReal64  powerRangeUpper);

ViStatus _VI_FUNC rspwrmeter_ConfigurePowerRatioRange(ViSession instrSession,
                                                      ViInt32   calculateBlock,
                                                      ViReal64  powerRatioRangeLower,
                                                      ViReal64  powerRatioRangeUpper);

ViStatus _VI_FUNC rspwrmeter_QueryFailedRange(ViSession  instrSession,
                                              ViInt32    calculateBlock,
                                              ViBoolean* failed,
                                              ViInt32*   failCount);

ViStatus _VI_FUNC rspwrmeter_ImmediateTrigger(ViSession instrSession,
                                              ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_ConfigureTrigger(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   triggerSource,
                                              ViInt32   triggerSlope,
                                              ViReal64  level,
                                              ViReal64  dropout,
                                              ViReal64  holdoff,
                                              ViReal64  hysteresis);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerDelay(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViBoolean delayAuto,
                                                   ViReal64  delay);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerMasterState(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean triggerMasterState);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerMasterPort(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   masterPort);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerSenderState(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean triggerSenderState);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerSenderPort(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   senderPort);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerSynchronizeState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean triggerSynchronizeState);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerSynchronizePort(ViSession instrSession,
                                                             ViInt32   triggerSynchronizePort);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerAuto(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViBoolean autoMode);

ViStatus _VI_FUNC rspwrmeter_GetTriggerAutoExecuted(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32*  executed);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerAutoLevel(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean autoLevel);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerAutoDelay(ViSession instrSession,
                                                       ViReal64  autoTriggerDelay);

ViStatus _VI_FUNC rspwrmeter_ConfigureExternalTriggerImpedance(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   impedance);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerCount(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   channelTriggerCount);

ViStatus _VI_FUNC rspwrmeter_ConfigureTriggerJitterSuppressionMethod(
                            ViSession instrSession,
                            ViInt32   jitterSuppressionMethod);

ViStatus _VI_FUNC rspwrmeter_GetTriggerJitterSuppressionCurrentValue(
                            ViSession instrSession,
                            ViInt32*  suppressionCurrentValue);

ViStatus _VI_FUNC rspwrmeter_GetTriggerJitterSuppressionTriggerOffset(
                            ViSession instrSession,
                            ViReal64* suppressionTriggerOffset);

ViStatus _VI_FUNC rspwrmeter_SensorReboot(ViSession instrSession,
                                          ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_SensorReset(ViSession instrSession,
                                         ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_SensorTest(ViSession instrSession,
                                        ViInt32   channel,
                                        ViInt32   arraySize,
                                        ViChar    testResult[]);

ViStatus _VI_FUNC rspwrmeter_SensorInfo(ViSession instrSession,
                                        ViInt32   channel,
                                        ViInt32   arraySize,
                                        ViChar    info[]);

ViStatus _VI_FUNC rspwrmeter_AutoOnce(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_AveragingReset(ViSession instrSession,
                                            ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_ConfigureAveragingTerminalControl(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   terminalControl);

ViStatus _VI_FUNC rspwrmeter_ConfigureAveragingDomain(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   averageDomain);

ViStatus _VI_FUNC rspwrmeter_ConfigureAveragingCount(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViBoolean averagingState,
                                                     ViInt32   count);

ViStatus _VI_FUNC rspwrmeter_ConfigureAutoFilterNSR(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViReal64  noiseContent,
                                                    ViReal64  maxSettlingTime);

ViStatus _VI_FUNC rspwrmeter_ConfigureAutoFilterResolution(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   resolution);

ViStatus _VI_FUNC rspwrmeter_ConfigureAutoFilterReferenceTimeslot(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   refTimeslot);

ViStatus _VI_FUNC rspwrmeter_ConfigureOffsetCorrection(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean correctionState,
                                                       ViReal64  correction);

ViStatus _VI_FUNC rspwrmeter_ConfigureTableOffsetCorrection(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean tableState,
                                                            ViString  selectedTable);

ViStatus _VI_FUNC rspwrmeter_QueryFDOffset(ViSession instrSession,
                                           ViInt32   channel,
                                           ViReal64* FDOffset);

ViStatus _VI_FUNC rspwrmeter_ConfigureSParameterDevice(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean sParameterState,
                                                       ViInt32   correction);

ViStatus _VI_FUNC rspwrmeter_GetSParameterDeviceList(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   bufferSize,
                                                     ViChar    deviceList[]);

ViStatus _VI_FUNC rspwrmeter_ConfigureSourceGammaCorrection(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean correctionState,
                                                            ViReal64  magnitude,
                                                            ViReal64  phase);

ViStatus _VI_FUNC rspwrmeter_ConfigureReflectionGammaCorrection(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  magnitude,
                            ViReal64  phase);

ViStatus _VI_FUNC rspwrmeter_ConfigureDutyCycleCorrection(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViBoolean correctionState,
                                                          ViReal64  correction);

ViStatus _VI_FUNC rspwrmeter_ConfigureNoiseCorrection(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViBoolean noiseCorrectionEnabled);

ViStatus _VI_FUNC rspwrmeter_QueryIGammaCorrection(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64* magnitude,
                                                   ViReal64* phase,
                                                   ViReal64* expandedUncertainty);

ViStatus _VI_FUNC rspwrmeter_ConfigureContAv(ViSession instrSession,
                                             ViInt32   channel,
                                             ViReal64  aperture,
                                             ViBoolean smoothingState,
                                             ViBoolean fastUnchoppedState);

ViStatus _VI_FUNC rspwrmeter_ConfigureContAvBuffer(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViBoolean bufferState,
                                                   ViInt32   bufferSize);

ViStatus _VI_FUNC rspwrmeter_GetContAvBufferCount(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32*  bufferCount);

ViStatus _VI_FUNC rspwrmeter_ClearContAvBuffer(ViSession instrSession,
                                               ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_ConfigureBurstAv(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64  dropoutTolerance,
                                              ViReal64  excludeStart,
                                              ViReal64  excludeStop);

ViStatus _VI_FUNC rspwrmeter_GetBurstAvLength(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64* length);

ViStatus _VI_FUNC rspwrmeter_ConfigureACLRApertureTime(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViReal64  ACLRApertureTime);

ViStatus _VI_FUNC rspwrmeter_GetACLRSpacing(ViSession instrSession,
                                            ViInt32   channel,
                                            ViReal64* ACLRSpacing);

ViStatus _VI_FUNC rspwrmeter_ConfigureVoltIQSampleRate(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViReal64  voltIQSampleRate);

ViStatus _VI_FUNC rspwrmeter_ConfigureVoltIQSampleCount(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   voltIQSampleCount);

ViStatus _VI_FUNC rspwrmeter_ConfigureTrace(ViSession instrSession,
                                            ViInt32   channel,
                                            ViReal64  time,
                                            ViReal64  traceOffsetTime,
                                            ViBoolean reserved,
                                            ViInt32   points);

ViStatus _VI_FUNC rspwrmeter_ConfigureTraceTimeAuto(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViBoolean traceTimeAuto);

ViStatus _VI_FUNC rspwrmeter_ConfigureTraceLimit(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  lowerLimit,
                                                 ViReal64  upperLimit);

ViStatus _VI_FUNC rspwrmeter_GetTraceMinimumSlotWidth(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64* minimumSlotWidth);

ViStatus _VI_FUNC rspwrmeter_GetNumberOfSamples(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32*  numberOfSamples);

ViStatus _VI_FUNC rspwrmeter_GetSampleRateForTrace(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64* sampleRateForTrace);

ViStatus _VI_FUNC rspwrmeter_ResetAverageCount(ViSession instrSession,
                                               ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_ConfigureTraceAveraging(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViBoolean averagingState,
                                                     ViBoolean countAuto,
                                                     ViInt32   count,
                                                     ViInt32   terminalControl);

ViStatus _VI_FUNC rspwrmeter_ConfigureTraceMeasurement(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean measurementState,
                                                       ViInt32   algorithm,
                                                       ViReal64  time,
                                                       ViReal64  timeOffset,
                                                       ViBoolean autoTransfer);

ViStatus _VI_FUNC rspwrmeter_ConfigureTraceTransitionMeasurement(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  referenceLevel,
                            ViReal64  highReference,
                            ViReal64  lowReference);

ViStatus _VI_FUNC rspwrmeter_QueryTraceTransitionMeasurement(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   edge,
                                                             ViReal64* duration,
                                                             ViReal64* occurrence,
                                                             ViReal64* overshoot);

ViStatus _VI_FUNC rspwrmeter_QueryTracePulseMeasurement(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViReal64* dutyCycle,
                                                        ViReal64* width,
                                                        ViReal64* period,
                                                        ViReal64* separation);

ViStatus _VI_FUNC rspwrmeter_QueryTracePowerMeasurement(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViReal64* average,
                                                        ViReal64* maximum,
                                                        ViReal64* minimum,
                                                        ViReal64* basePower,
                                                        ViReal64* topPower);

ViStatus _VI_FUNC rspwrmeter_QueryTracePulseDroop(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViReal64* droop);

ViStatus _VI_FUNC rspwrmeter_ConfigureStatisticsTimegate(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViReal64  offset,
                                                         ViReal64  time);

ViStatus _VI_FUNC rspwrmeter_ConfigureStatisticsTimegateFence(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  midambleOffset,
                            ViReal64  midambleLength);

ViStatus _VI_FUNC rspwrmeter_ConfigureStatisticsScale(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64  referenceLevel,
                                                      ViReal64  range,
                                                      ViInt32   points);

ViStatus _VI_FUNC rspwrmeter_ConfigureStatisticsMinimumSamples(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   samples);

ViStatus _VI_FUNC rspwrmeter_ConfigureStatisticsMeasurement(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViReal64  power,
                                                            ViReal64  verticalPosition);

ViStatus _VI_FUNC rspwrmeter_QueryStatisticsMeasurement(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViReal64* horizontalData,
                                                        ViReal64* absolutePowerPosition,
                                                        ViReal64* peakPower,
                                                        ViReal64* average);

ViStatus _VI_FUNC rspwrmeter_QueryStatisticsScaleMinimumWidth(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64* minimumWidth);

ViStatus _VI_FUNC rspwrmeter_ReadStatisticsAverageData(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViReal64* averageData);

ViStatus _VI_FUNC rspwrmeter_ConfigureTimeslot(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   timeSlotCount,
                                               ViReal64  width);

ViStatus _VI_FUNC rspwrmeter_ConfigureTimeslotInterval(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViReal64  excludeStart,
                                                       ViReal64  excludeStop);

ViStatus _VI_FUNC rspwrmeter_ConfigureTimeslotFence(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViBoolean midambleState,
                                                    ViReal64  midambleOffset,
                                                    ViReal64  midambleLength);

ViStatus _VI_FUNC rspwrmeter_SelectedTimegate(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   timegate);

ViStatus _VI_FUNC rspwrmeter_ConfigureTimegate(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   timegate,
                                               ViReal64  offset,
                                               ViReal64  time,
                                               ViBoolean midambleState,
                                               ViReal64  midambleOffset,
                                               ViReal64  midambleLength);

ViStatus _VI_FUNC rspwrmeter_ConfigureRefOscillatorEnabled(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViBoolean refOscillatorState);

ViStatus _VI_FUNC rspwrmeter_ConfigureReferenceOscillator(ViSession instrSession,
                                                          ViInt32   referenceOscillatorSource,
                                                          ViReal64  referenceOscillatorFrequency);

ViStatus _VI_FUNC rspwrmeter_ConfigureSMAConnectorOutput(ViSession instrSession,
                                                         ViBoolean referenceIOOutputEnabled,
                                                         ViBoolean sampleClockOutputEnabled);

ViStatus _VI_FUNC rspwrmeter_WriteCalibrationData(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   dataBlock,
                                                  ViInt32   arraySize,
                                                  ViChar    data[]);

ViStatus _VI_FUNC rspwrmeter_ReadCalibrationData(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   dataBlock,
                                                 ViInt32   arraySize,
                                                 ViChar    data[]);

ViStatus _VI_FUNC rspwrmeter_GetTestDeviation(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64* testDeviation);

ViStatus _VI_FUNC rspwrmeter_GetTestReference(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64* testReference);

ViStatus _VI_FUNC rspwrmeter_GetDataBlockLength(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   dataBlock,
                                                ViInt32*  length);

ViStatus _VI_FUNC rspwrmeter_Autoset(ViSession instrSession,
                                     ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_AutosetFrequency(ViSession instrSession,
                                              ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_AutosetInputAttenuation(ViSession instrSession,
                                                     ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_ConfigureBandwidthType(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   bandwidthType);

ViStatus _VI_FUNC rspwrmeter_ConfigureResolutionBandwidth(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViReal64  resolutionBandwidth);

ViStatus _VI_FUNC rspwrmeter_GetCurrentResolutionBandwidth(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViReal64* currentResolutionBandwidth);

ViStatus _VI_FUNC rspwrmeter_ConfigureFilterType(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViBoolean autosetFilterType,
                                                 ViInt32   filterType);

ViStatus _VI_FUNC rspwrmeter_ConfigureInputAttenuationAuto(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViBoolean inputAttenuationAuto,
                                                           ViReal64  inputAttenuation);

ViStatus _VI_FUNC rspwrmeter_ConfigureLocalOscillatorOutput(ViSession instrSession,
                                                            ViBoolean oscillatorOutputEnabled);

ViStatus _VI_FUNC rspwrmeter_GetLocalOscillatorFrequency(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViReal64* localOscillatorFrequency);

ViStatus _VI_FUNC rspwrmeter_ConfigureIFSideband(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViBoolean IFSidebandAutoEnabled,
                                                 ViInt32   IFSidebandSelected);

ViStatus _VI_FUNC rspwrmeter_GetIFSidebandFrequency(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViReal64* IFSidebandFrequency);

ViStatus _VI_FUNC rspwrmeter_ConfigureFrequencyTracking(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViBoolean frequencyTrackingEnabled);

ViStatus _VI_FUNC rspwrmeter_GetFrequencyTrackingCurrentState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  trackingCurrentState);

ViStatus _VI_FUNC rspwrmeter_GetFrequencyTrackingCurrentFrequency(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64* trackingCurrentFrequency);

ViStatus _VI_FUNC rspwrmeter_Zero(ViSession instrSession,
                                  ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_FastZero(ViSession instrSession,
                                      ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_IsZeroComplete(ViSession  instrSession,
                                            ViInt32    channel,
                                            ViBoolean* zeroingComplete);

ViStatus _VI_FUNC rspwrmeter_ReadMeasurement(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   timeout,
                                             ViReal64* measurement);

ViStatus _VI_FUNC rspwrmeter_FetchMeasurement(ViSession instrSession,
                                              ViInt32   channel,
                                              ViUInt32  bufferSize,
                                              ViReal64  measurement[],
                                              ViUInt32* returnedValues);

ViStatus _VI_FUNC rspwrmeter_FetchIqData(ViSession instrSession,
                                         ViInt32   channel,
                                         ViUInt32  bufferSize,
                                         ViReal64  iData[],
                                         ViReal64  qData[],
                                         ViUInt32* returnedValues);

ViStatus _VI_FUNC rspwrmeter_FetchAllPaths(ViSession instrSession,
                                           ViInt32   channel,
                                           ViUInt32  bufferSize,
                                           ViReal64  measurement[],
                                           ViUInt32* returnedValues);

ViStatus _VI_FUNC rspwrmeter_FetchAllPathsBuffered(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViUInt32  bufferSize,
                                                   ViReal64  measurement[],
                                                   ViUInt32* returnedValues);

ViStatus _VI_FUNC rspwrmeter_SendSoftwareTrigger(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_ResetRelativeMeasurement(ViSession instrSession,
                                                      ViInt32   calculateBlock);

ViStatus _VI_FUNC rspwrmeter_ConfigureRelativeMeasurement(ViSession instrSession,
                                                          ViInt32   calculateBlock,
                                                          ViBoolean state,
                                                          ViReal64  reference,
                                                          ViReal64  referencePowerRatio);

ViStatus _VI_FUNC rspwrmeter_ConfigureMathExpression(ViSession instrSession,
                                                     ViInt32   calculateBlock,
                                                     ViString  expression);

ViStatus _VI_FUNC rspwrmeter_GetMathExpressionCatalog(ViSession instrSession,
                                                      ViInt32   calculateBlock,
                                                      ViInt32   bufferSize,
                                                      ViChar    mathExpressionList[]);

ViStatus _VI_FUNC rspwrmeter_SetTraceMarkerXPosition(ViSession instrSession,
                                                     ViInt32   calculateBlock,
                                                     ViInt32   marker,
                                                     ViReal64  xPosition);

ViStatus _VI_FUNC rspwrmeter_GetTraceMarkerXPosition(ViSession instrSession,
                                                     ViInt32   calculateBlock,
                                                     ViInt32   marker,
                                                     ViReal64* xPosition);

ViStatus _VI_FUNC rspwrmeter_GetTraceMarkerYPosition(ViSession instrSession,
                                                     ViInt32   calculateBlock,
                                                     ViInt32   marker,
                                                     ViReal64* yPosition);

ViStatus _VI_FUNC rspwrmeter_QueryTraceMarkerDelta(ViSession instrSession,
                                                   ViInt32   calculateBlock,
                                                   ViReal64* xDelta,
                                                   ViReal64* yDelta);

ViStatus _VI_FUNC rspwrmeter_QueryDisplayedData(ViSession instrSession,
                                                ViInt32   calculateBlock,
                                                ViInt32*  dataCount,
                                                ViReal64* data,
                                                ViReal64* standardDeviation,
                                                ViReal64* mean,
                                                ViReal64* peakToPeak,
                                                ViReal64* maximum,
                                                ViReal64* minimum);

ViStatus _VI_FUNC rspwrmeter_AbortAll(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_InitiateAll(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_InitiateAllAndWait(ViSession instrSession,
                                                ViInt32   timeout);

ViStatus _VI_FUNC rspwrmeter_DisableInitiateAll(ViSession instrSession,
                                                ViBoolean disableInitiate);

ViStatus _VI_FUNC rspwrmeter_SetInitContinuousStateAll(ViSession instrSession,
                                                       ViBoolean continuousState);

ViStatus _VI_FUNC rspwrmeter_QueryMeasPathSensorPresent(ViSession  instrSession,
                                                        ViInt32    sensorNumber,
                                                        ViBoolean* sensorPresent);

ViStatus _VI_FUNC rspwrmeter_ConfigureMeasPathSensorEnabled(ViSession instrSession,
                                                            ViInt32   sensorNumber,
                                                            ViBoolean sensorEnabled);

ViStatus _VI_FUNC rspwrmeter_Abort(ViSession instrSession,
                                   ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_Initiate(ViSession instrSession,
                                      ViInt32   channel);

ViStatus _VI_FUNC rspwrmeter_InitiateAndWait(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   timeout);

ViStatus _VI_FUNC rspwrmeter_DisableInitiate(ViSession instrSession,
                                             ViInt32   channel,
                                             ViBoolean disableInitiate);

ViStatus _VI_FUNC rspwrmeter_SetInitContinuousState(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViBoolean continuousState);

ViStatus _VI_FUNC rspwrmeter_GetInitContinuousState(ViSession  instrSession,
                                                    ViInt32    channel,
                                                    ViBoolean* continuousState);

ViStatus _VI_FUNC rspwrmeter_GetTraceData(ViSession instrSession,
                                          ViInt32   channel,
                                          ViInt32   arraySize,
                                          ViReal64  traceData[],
                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rspwrmeter_GetTraceDataWithAuxiliary(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   arraySize,
                                                       ViInt32   expectedDataSize,
                                                       ViReal64  traceData[],
                                                       ViInt32   resultType[],
                                                       ViInt32   returnedDataSize[],
                                                       ViInt32*  returnedSections);

ViStatus _VI_FUNC rspwrmeter_GetBufferData(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   arraySize,
                                           ViReal64  bufferData[],
                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rspwrmeter_FetchResults(ViSession instrSession,
                                          ViInt32   channel,
                                          ViInt32   measurement,
                                          ViInt32   arraySize,
                                          ViReal64  results[],
                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rspwrmeter_SecurityPassword(ViSession instrSession,
                                              ViString  oldPassword,
                                              ViString  newPassword);

ViStatus _VI_FUNC rspwrmeter_UserPassword(ViSession instrSession,
                                          ViString  oldPassword,
                                          ViString  newPassword);

ViStatus _VI_FUNC rspwrmeter_Preset(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_SystemVersion(ViSession instrSession,
                                           ViInt32   length,
                                           ViChar    systemVersion[]);

ViStatus _VI_FUNC rspwrmeter_SystemInformation(ViSession instrSession,
                                               ViInt32   length,
                                               ViChar    systemInformation[]);

ViStatus _VI_FUNC rspwrmeter_SystemClockSource(ViSession instrSession,
                                               ViInt32   clockSource);

ViStatus _VI_FUNC rspwrmeter_ConfigureLED(ViSession instrSession,
                                          ViInt32   LEDMode,
                                          ViInt32   red,
                                          ViInt32   green,
                                          ViInt32   blue);

ViStatus _VI_FUNC rspwrmeter_QueryLowerPowerMeasurementLimit(ViSession instrSession,
                                                             ViReal64* lowerPowerMeasurementLimit);

ViStatus _VI_FUNC rspwrmeter_ConfigureIPAddress(ViSession instrSession,
                                                ViInt32   mode,
                                                ViString  IPAddress,
                                                ViString  subnetMask,
                                                ViString  gateway);

ViStatus _VI_FUNC rspwrmeter_GetIPAddressInfo(ViSession instrSession,
                                              ViInt32   length,
                                              ViChar    info[]);

ViStatus _VI_FUNC rspwrmeter_GetNetworkStatus(ViSession instrSession,
                                              ViInt32   length,
                                              ViChar    status[]);

ViStatus _VI_FUNC rspwrmeter_ResetNetworkSettings(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_RestartNetworkSettings(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_ConfigureCommonSettings(ViSession instrSession,
                                                     ViString  domain,
                                                     ViString  hostname);

ViStatus _VI_FUNC rspwrmeter_ConfigureSocket(ViSession instrSession,
                                             ViInt32   mode,
                                             ViInt32   port);

ViStatus _VI_FUNC rspwrmeter_SetStatusRegister(ViSession instrSession,
                                               ViInt32   registerGroup,
                                               ViUInt16  enable,
                                               ViUInt16  PTransition,
                                               ViUInt16  NTransition);

ViStatus _VI_FUNC rspwrmeter_GetStatusRegister(ViSession instrSession,
                                               ViInt32   registerGroup,
                                               ViInt32   registerPart,
                                               ViUInt16* registerValue);

ViStatus _VI_FUNC rspwrmeter_PresetStatusRegisters(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_SetAttributeViInt32(ViSession instrSession,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViInt32   attributeValue);

ViStatus _VI_FUNC rspwrmeter_SetAttributeViReal64(ViSession instrSession,
                                                  ViString  repeatedCapabilityName,
                                                  ViUInt32  attributeID,
                                                  ViReal64  attributeValue);

ViStatus _VI_FUNC rspwrmeter_SetAttributeViString(ViSession instrSession,
                                                  ViString  repeatedCapabilityName,
                                                  ViUInt32  attributeID,
                                                  ViString  attributeValue);

ViStatus _VI_FUNC rspwrmeter_SetAttributeViBoolean(ViSession instrSession,
                                                   ViString  repeatedCapabilityName,
                                                   ViUInt32  attributeID,
                                                   ViBoolean attributeValue);

ViStatus _VI_FUNC rspwrmeter_GetAttributeRepCapName(ViSession instrSession,
                                                    ViUInt32  attributeID,
                                                    ViString  repCapNameID,
                                                    ViInt32   index,
                                                    ViInt32   bufferSize,
                                                    ViChar    repCapName[]);

ViStatus _VI_FUNC rspwrmeter_GetAttributeRepeatedCapabilityIds(
                            ViSession instrSession,
                            ViUInt32  attributeID,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIds[]);

ViStatus _VI_FUNC rspwrmeter_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViUInt32  attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[]);

ViStatus _VI_FUNC rspwrmeter_GetAttributeViInt32(ViSession instrSession,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViInt32*  attributeValue);

ViStatus _VI_FUNC rspwrmeter_GetAttributeViReal64(ViSession instrSession,
                                                  ViString  repeatedCapabilityName,
                                                  ViUInt32  attributeID,
                                                  ViReal64* attributeValue);

ViStatus _VI_FUNC rspwrmeter_GetAttributeViString(ViSession instrSession,
                                                  ViString  repeatedCapabilityName,
                                                  ViUInt32  attributeID,
                                                  ViInt32   bufferSize,
                                                  ViChar    attributeValue[]);

ViStatus _VI_FUNC rspwrmeter_GetAttributeViBoolean(ViSession  instrSession,
                                                   ViString   repeatedCapabilityName,
                                                   ViUInt32   attributeID,
                                                   ViBoolean* attributeValue);

ViStatus _VI_FUNC rspwrmeter_reset(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_self_test(ViSession instrSession,
                                       ViInt16*  selfTestResult,
                                       ViChar    selfTestMessage[]);

ViStatus _VI_FUNC rspwrmeter_revision_query(ViSession instrSession,
                                            ViChar    instrumentDriverRevision[],
                                            ViChar    firmwareRevision[]);

ViStatus _VI_FUNC rspwrmeter_error_query(ViSession instrSession,
                                         ViInt32*  errorCode,
                                         ViChar    errorMessage[]);

ViStatus _VI_FUNC rspwrmeter_error_message(ViSession instrSession,
                                           ViStatus  errorCode,
                                           ViChar    errorMessage[]);

ViStatus _VI_FUNC rspwrmeter_ReadErrorCount(ViSession instrSession,
                                            ViInt32*  numberOfErrors);

ViStatus _VI_FUNC rspwrmeter_ReadAllErrors(ViSession instrSession,
                                           ViUInt32  numberOfBytesToRead,
                                           ViChar    readBuffer[],
                                           ViUInt32* numBytesRead);

ViStatus _VI_FUNC rspwrmeter_ReadAllStaticErrors(ViSession instrSession,
                                                 ViInt32*  errorCode,
                                                 ViChar    errorMessage[]);

ViStatus _VI_FUNC rspwrmeter_SetTimeout(ViSession instrSession,
                                        ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rspwrmeter_GetTimeout(ViSession instrSession,
                                        ViUInt32* timeout);

ViStatus _VI_FUNC rspwrmeter_SetVISATimeout(ViSession instrSession,
                                            ViUInt32  VISATimeout);

ViStatus _VI_FUNC rspwrmeter_GetVISATimeout(ViSession instrSession,
                                            ViUInt32* VISATimeout);

ViStatus _VI_FUNC rspwrmeter_ConfigureErrorChecking(ViSession instrSession,
                                                    ViBoolean optionChecking,
                                                    ViBoolean rangeChecking,
                                                    ViBoolean statusChecking);

ViStatus _VI_FUNC rspwrmeter_ClearStatus(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_IDQueryResponse(ViSession instrSession,
                                             ViUInt32  bufferSize,
                                             ViChar    IDQueryResponse[]);

ViStatus _VI_FUNC rspwrmeter_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_QueryOPC(ViSession instrSession,
                                      ViInt32*  OPC);

ViStatus _VI_FUNC rspwrmeter_GetDeviceFootprint(ViSession instrSession,
                                                ViInt32   channel,
                                                ViUInt32  bufferSize,
                                                ViChar    deviceFootprint[],
                                                ViUInt32* returnedValues);

ViStatus _VI_FUNC rspwrmeter_GetSystemTestLevels(ViSession instrSession,
                                                 ViInt32*  systemTestLevels);

ViStatus _VI_FUNC rspwrmeter_SetSystemSensorName(ViSession instrSession,
                                                 ViString  systemSensorName);

ViStatus _VI_FUNC rspwrmeter_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                         ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rspwrmeter_IsBaseUnit(ViSession  instrSession,
                                        ViBoolean* isBaseUnit);

ViStatus _VI_FUNC rspwrmeter_GetBaseUnitSensorsPresence(ViSession  instrSession,
                                                        ViBoolean* channel1,
                                                        ViBoolean* channel2,
                                                        ViBoolean* channel3,
                                                        ViBoolean* channel4);

ViStatus _VI_FUNC rspwrmeter_ConfigureMultiThreadLocking(ViSession instrSession,
                                                         ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rspwrmeter_SaveCommands(ViSession instrSession,
                                          ViInt32   type,
                                          ViString  targetPCFile);

ViStatus _VI_FUNC rspwrmeter_OPCSyncWriteEnable(ViSession instrSession,
                                                ViBoolean enable);

ViStatus _VI_FUNC rspwrmeter_OPCSyncQueryEnable(ViSession instrSession,
                                                ViBoolean enable);

ViStatus _VI_FUNC rspwrmeter_SetOpcSyncQueryMechanism(ViSession instrSession,
                                                      ViBoolean useESB,
                                                      ViBoolean CLSBefore,
                                                      ViBoolean useMAV);

ViStatus _VI_FUNC rspwrmeter_GetError(ViSession instrSession,
                                      ViStatus* code,
                                      ViInt32   bufferSize,
                                      ViChar    description[]);

ViStatus _VI_FUNC rspwrmeter_ClearError(ViSession instrSession);

ViStatus _VI_FUNC rspwrmeter_viWrite(ViSession instrSession,
                                     ViString  writeBuffer,
                                     ViUInt32  count,
                                     ViUInt32* returnCount);

ViStatus _VI_FUNC rspwrmeter_QueryViBoolean(ViSession  instrSession,
                                            ViString   command,
                                            ViBoolean* value);

ViStatus _VI_FUNC rspwrmeter_QueryViInt32(ViSession instrSession,
                                          ViString  command,
                                          ViInt32*  value);

ViStatus _VI_FUNC rspwrmeter_QueryViReal64(ViSession instrSession,
                                           ViString  command,
                                           ViReal64* value);

ViStatus _VI_FUNC rspwrmeter_QueryViString(ViSession instrSession,
                                           ViString  command,
                                           ViInt32   bufferSize,
                                           ViChar    value[]);

ViStatus _VI_FUNC rspwrmeter_close(ViSession instrSession);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSPWRMETER_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSPWRMETER_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSPWRMETER_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSPWRMETER_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSPWRMETER_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSPWRMETER_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSPWRMETER_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSPWRMETER_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSPWRMETER_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSPWRMETER_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSPWRMETER_ERROR_CODES_AND_MSGS \
    {RSPWRMETER_WARN_MEASURE_UNCALIBRATED,  RSPWRMETER_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSPWRMETER_WARN_OVER_RANGE,            RSPWRMETER_WARNMSG_OVER_RANGE},\
    {RSPWRMETER_ERROR_INCORRECT_STATE ,   RSPWRMETER_ERRMSG_INCORRECT_STATE },\
    {RSPWRMETER_ERROR_INCORRECT_RESPONSE,     RSPWRMETER_ERRMSG_INCORRECT_RESPONSE},\
    {RSPWRMETER_ERROR_MAX_TIME_EXCEEDED,    RSPWRMETER_ERRMSG_MAX_TIME_EXCEEDED}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSPWRMETER_HEADER */
